diff --git a/Apollo/api/application/controllers/Report.php b/Apollo/api/application/controllers/Report.php
index 10ffdf1b..e61fc126 100755
--- a/Apollo/api/application/controllers/Report.php
+++ b/Apollo/api/application/controllers/Report.php
@@ -383,10 +383,8 @@ class Report extends REST_Controller {
}
-
-
-
-
+
+
public function getAllUniversity_post()
{
@@ -443,8 +441,6 @@ class Report extends REST_Controller {
}
-
-
diff --git a/Apollo/api/application/models/Dashboard_model.php b/Apollo/api/application/models/Dashboard_model.php
index 0c4b2b77..9393025c 100755
--- a/Apollo/api/application/models/Dashboard_model.php
+++ b/Apollo/api/application/models/Dashboard_model.php
@@ -81,7 +81,6 @@ class Dashboard_model extends CI_Model
$this->db->where('BranchCode',$details['localBranchID']);
$getUnivDetails = $this->db->get();
if($getUnivDetails->result()){
- $resultDetails['resultStatus']=true;
foreach ($getUnivDetails->result() as $rows){
$fetchDetails['UniversityID']=$rows->UniversityID;
$fetchDetails['UniversityName']=$rows->UniversityName;
@@ -103,9 +102,12 @@ class Dashboard_model extends CI_Model
$resultDetails['universityFeesDetails']=$getFeesArray;
}
else{
- $resultDetails['resultStatus']=false;
+ $resultDetails['details']=false;
$resultDetails['Message']="No records found!";
+ $resultDetails['universityFeesDetails']=false;
}
+ $resultDetails['batchFeesDetails']=$this->getBatchPendingFees($details['localBranchID']);
+
return $resultDetails;
}
/*
@@ -116,7 +118,6 @@ class Dashboard_model extends CI_Model
$feesDetails=array();
$feesDetails['UniversityID']=$universityID;
$feesDetails['UniversityName']=$universityName;
-
$this->db->select("SUM(SFS.CourseFees) as PayableFees");
$this->db->from( STUDENTS_FEES_STATUS . ' as SFS');
$this->db->join( COURSE . ' as CU', 'CU.CourseID = SFS.CourseID');
@@ -138,6 +139,7 @@ class Dashboard_model extends CI_Model
$this->db->join( COURSE . ' as CU', 'CU.CourseID = SFS.CourseID');
$this->db->where('CU.UniversityID',$universityID);
$this->db->where('CU.BranchCode',$branchCode);
+ $this->db->where('SFP.IsActive','1');
$this->db->order_by('CU.CourseID','DESC');
$getUnivPaidFeesDetails = $this->db->get();
if($getUnivPaidFeesDetails->result()){
@@ -153,6 +155,64 @@ class Dashboard_model extends CI_Model
}
+ /*
+ * get batch pending fees details
+ * created by kms
+ * */
+ public function getBatchPendingFees($branchCode=null){
+ $this->db->distinct();
+ $this->db->select('BatchCode,BatchName');
+ $this->db->from(BATCH);
+ $this->db->order_by('BatchID','DESC');
+ $this->db->where('BranchCode',$branchCode);
+ $getBatchDetails = $this->db->get();
+ if($getBatchDetails->result()){
+ foreach ($getBatchDetails->result() as $bRows){
+ $batchFeesDetails['BatchCode']=$bRows->BatchCode;
+ $batchFeesDetails['BatchName']=$bRows->BatchName;
+ $this->db->select("SUM(SFS.CourseFees) as PayableFees");
+ $this->db->from( STUDENTS_FEES_STATUS . ' as SFS');
+ $this->db->where('SFS.BatchCode',$bRows->BatchCode);
+ $this->db->where('SFS.BranchCode',$branchCode);
+ $getBatchFeesDetails = $this->db->get();
+ if($getBatchFeesDetails->result()){
+ foreach ($getBatchFeesDetails->result() as $bpayableRow){
+ $batchFeesDetails['PayableFees']=$bpayableRow->PayableFees;
+ }
+ }
+ else{
+ $batchFeesDetails['PayableFees']=0;
+ }
+ // get paid details
+ $this->db->select("SUM(SFP.BillAmount) as PaidFees");
+ $this->db->from( STUDENTS_FEES_PAID . ' as SFP');
+ $this->db->join( STUDENTS_FEES_STATUS . ' as SFS', 'SFS.FeesID = SFP.FeesId');
+ $this->db->where('SFP.IsActive','1');
+ $this->db->where('SFS.BatchCode',$bRows->BatchCode);
+ $this->db->where('SFS.BranchCode',$branchCode);
+ $getBatchPaidFeesDetails = $this->db->get();
+ if($getBatchPaidFeesDetails->result()){
+ foreach ($getBatchPaidFeesDetails->result() as $bpaidRow){
+ $batchFeesDetails['PaidFees']=$bpaidRow->PaidFees;
+ }
+ }
+ else{
+ $batchFeesDetails['PaidFees']=0;
+ }
+ $fetchBatchFees[]=$batchFeesDetails;
+
+ }
+
+ return $fetchBatchFees;
+ }
+ else{
+ return false;
+ }
+
+
+
+ }
+
}
\ No newline at end of file
diff --git a/Apollo/api/application/models/Hallticket_model.php b/Apollo/api/application/models/Hallticket_model.php
index 055c008c..7248a4ea 100755
--- a/Apollo/api/application/models/Hallticket_model.php
+++ b/Apollo/api/application/models/Hallticket_model.php
@@ -810,7 +810,7 @@ class Hallticket_model extends CI_Model
}
- array_splice($id['FeeDetails'][$key2],0,6,$in1);
+ array_splice($id['FeeDetails'][$key2],0,6,$in1[0]);
}
@@ -832,7 +832,7 @@ class Hallticket_model extends CI_Model
// }
- array_splice($id['FeeDetails'][$key2],0,6,$in2);
+ array_splice($id['FeeDetails'][$key2],0,6,$in2[0]);
}
@@ -854,7 +854,7 @@ class Hallticket_model extends CI_Model
// }
- array_splice($id['FeeDetails'][$key2],0,6,$in3);
+ array_splice($id['FeeDetails'][$key2],0,6,$in3[0]);
}
@@ -876,7 +876,7 @@ class Hallticket_model extends CI_Model
// }
- array_splice($id['FeeDetails'][$key2],0,6,$in4);
+ array_splice($id['FeeDetails'][$key2],0,6,$in4[0]);
}
$studentIDs['NUMTYPE'] = 'YEAR';
@@ -1031,8 +1031,10 @@ class Hallticket_model extends CI_Model
{
foreach($studentIDs as $student)
{
+
if(!empty($student['FeeDetails']))
{
+
foreach($student['FeeDetails'][0] as $key => $fees)
{
@@ -1045,16 +1047,13 @@ class Hallticket_model extends CI_Model
$HallTicketStudentID = $this->db->insert_id();
$this->db->trans_complete();
- foreach($fees as $subject)
- {
-
- $tempSubjectArray = array('HallTicket_Student_ID'=>$HallTicketStudentID,'SubjectCode'=>$subject->SubjectID,'ExamDate'=>$subject->ScheduleDate,'FromTime'=>$subject->FromTime,'EndTime'=>$subject->ToTime);
+ $tempSubjectArray = array('HallTicket_Student_ID'=>$HallTicketStudentID,'SubjectCode'=>$fees->SubjectID,'ExamDate'=>$fees->ScheduleDate,'FromTime'=>$fees->FromTime,'EndTime'=>$fees->ToTime);
$this->db->trans_start();
$this->db->insert('T_Hallticket_Subject_Details',$tempSubjectArray);
$this->db->trans_complete();
- }
+
}
}
}
diff --git a/Apollo/api/application/models/Reports_model.php b/Apollo/api/application/models/Reports_model.php
index 532b02e6..a2f44e14 100755
--- a/Apollo/api/application/models/Reports_model.php
+++ b/Apollo/api/application/models/Reports_model.php
@@ -34,7 +34,7 @@ order by CourseID) as cm
on cm.cid=cfd.ccid
left join
(SELECT StudentID as sid,MobileNumber as phone,IsActive as active,FirstName as name,Fathername as father,AlternateNumber,PresentAddress as address FROM T_StudentDetails where IsActive = 1) as std on std.sid=sms.sid
-left join (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,EnrollmentID as eid,BranchID as branch FROM T_Student_CourseDetails) as scd on scd.sid=sms.sid and scd.cid=sms.cid
+left join (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,EnrollmentID as eid,BranchID as branch FROM T_Student_CourseDetails) as scd on scd.sid=sms.sid
where sms.branch = '".$br."'
";
@@ -433,26 +433,24 @@ group by sid
}
public function app_pending($bat=null,$br=null,$u=null){
- $sql = "select ifnull(sms.sid,'-') as Student_id,ifnull(scd.eid,'-') as Enrollment_id,ifnull(std.name,'-') as Student_name,ifnull(std.father,'-') as Father_name,ifnull(std.phone,'-') as Phone_number,ifnull(sms.cid,'-') as Course_id,ifnull(cfd.syear,'-') as Sem_year,ifnull(sfs.batch,'-') as Batch_code,ifnull(sms.branch,'-') as Branch_code,ifnull(cm.course,'-') as Course_name,ifnull(cm.uname,'-') as University,ifnull(sms.status,'-') as Status,ifnull(sfp.bdate,'-') as Admission_date,
- ifnull(std.address,'-') as address,ifnull(std.AlternateNumber,'') as AlternateNumber,sms.adate as appdate
+ $sql = "select ifnull(sms.sid,'-') as Student_id,ifnull(scd.eid,'-') as Enrollment_id,ifnull(std.name,'-') as Student_name,ifnull(std.father,'-') as Father_name,ifnull(std.phone,'-') as Phone_number,ifnull(sms.cid,'-') as Course_id,ifnull(cfd.syear,'-') as Sem_year,ifnull(sms.branch,'-') as Branch_code,ifnull(cm.course,'-') as Course_name,ifnull(cm.uname,'-') as University,ifnull(sms.status,'-') as Status,ifnull(sfp.bdate,'-') as Admission_date,
+ sms.adate as appdate,ifnull(reg.formtype,'-') as formtype,sfs.batch as batch
from
- (SELECT ID,StudentID as sid,CourseID as cid,app.BranchCode as branch,list.ListName as status,app.ListCode as lcode,AppDate as adate,Comments as acmts,CertificationType as ctype,CertificateName as certname FROM T_ApplicationStatus as app
+ (SELECT ID,StudentID as sid,CourseID as cid,app.BranchCode as branch,list.ListName as status,app.ListCode as lcode,AppDate as adate,Comments as acmts,app.CertificationType as ctype,CertificateName as certname
+FROM T_ApplicationStatus as app
left join T_CertificationMaster cm on cm.CertificationID=app.CertificationType
left join T_PickListDetails list on list.ListCode=app.ListCode
-where CertificateName like 'APPLICATION%' and list.ListName != 'SENT TO UNIVERSITY' and ID IN (SELECT max(ID) FROM T_ApplicationStatus group by StudentID,CourseID,BranchCode)
-group by sid,cid,lcode,branch) as sms
-left join
- (SELECT FeesID as fid,BatchCode as batch,StudentID as sid,CourseID as cid,FeesType as ftype, sum(CourseFees) as cf,Sum(STFOrWR) as stf,sum(Others) as others
- FROM T_Students_Fees_Status
- group by sid,fid,cid,batch)
- as sfs on sfs.sid=sms.sid and sms.cid=sfs.cid
+where CertificateName like 'APPLICATION%' and list.ListName != 'SENT TO UNIVERSITY' and ID IN (SELECT max(ID) FROM T_ApplicationStatus group by StudentID,CourseID,BranchCode,CertificationType,ListCode)
+group by sid,cid,lcode,branch,ctype) as sms
+left join
+(select StudentID as sid,CourseID as cid,BatchCode as batch,FeesID as fid from T_Students_Fees_Status) as sfs on sfs.sid=sms.sid and sfs.cid=sms.cid
left join
(SELECT ID,StudentID as sid,FeesId as fid,BillDate as bdate,sum(BillAmount) as bamount,BillNO as billno FROM T_Students_Fees_PaidDetails
WHERE IsActive = 1 and ID IN (SELECT min(ID) FROM T_Students_Fees_PaidDetails group by StudentID,FeesID)
group by sid,fid,billno)
- as sfp on sfp.sid=sfs.sid and sfp.fid=sfs.fid
+ as sfp on sfp.sid=sfs.sid and sfs.fid=sfp.fid
left join
- (SELECT ID as cid,CourseID as ccid,FeesType as ftype,Sem_Year as syear FROM T_Course_Fees_Details) as cfd on cfd.ccid=sfs.cid and cfd.cid=sfs.ftype
+ (SELECT ID as cid,CourseID as ccid,FeesType as ftype,Sem_Year as syear FROM T_Course_Fees_Details) as cfd on cfd.ccid=sms.cid
left join
(SELECT CourseID as cid,cm.UniversityID as cuid,u.UniversityID as uid,CourseName as course,
UniversityName as uname,cm.BranchCode as branch FROM T_CourseMaster as cm
@@ -463,6 +461,9 @@ left join
left join
(SELECT StudentID as sid,MobileNumber as phone,IsActive as active,FirstName as name,Fathername as father,PermanentAddress as address,AlternateNumber FROM T_StudentDetails) as std on std.sid=sms.sid
left join (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,EnrollmentID as eid,BranchID as branch FROM T_Student_CourseDetails) as scd on scd.sid=sms.sid and scd.cid=sms.cid and scd.branch=sms.branch
+left join
+(Select StudentID as sid,CourseID as cid,BatchCode as bcode,FeeType as ftype,BranchCode as branch,RegistrationType as formtype from T_Registration_Details) as reg on reg.sid=sms.sid and reg.cid=sms.cid
+
where std.active = 1 and sms.branch = '".$br."'
";
@@ -476,7 +477,7 @@ left join (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,Enrollmen
$sql.=" and cm.uid = '".$u."'";
}
- $sql.=" group by Student_id,Course_id,Batch_code,Branch_code,Sem_year";
+ $sql.=" group by Student_id,Course_id,Branch_code,Sem_year";
@@ -618,26 +619,23 @@ left join
}
public function examfee($bat=null,$br=null,$u=null){
- $sql = "select ifnull(sms.sid,'-') as Student_id,ifnull(scd.eid,'-') as Enrollment_id,ifnull(std.name,'-') as Student_name,ifnull(std.father,'-') as Father_name,ifnull(std.phone,'-') as Phone_number,ifnull(cfd.syear,'-') as Sem_year,ifnull(sfs.batch,'-') as Batch_code,ifnull(cm.course,'-') as Course_name,ifnull(cm.uname,'-') as University,ifnull(sfs.cid,'-') as Course_id,ifnull(sms.cmts,'-') as Comments,ifnull(sms.stf,'-') as Amount,ifnull(sms.branch,'-') as Branch_code,ifnull(std.address,'-') as address,ifnull(std.AlternateNumber,'') as AlternateNumber
+ $sql = "select ifnull(sms.sid,'-') as Student_id,ifnull(scd.eid,'-') as Enrollment_id,ifnull(std.name,'-') as Student_name,ifnull(std.father,'-') as Father_name,ifnull(std.phone,'-') as Phone_number,ifnull(cfd.syear,'-') as Sem_year,ifnull(sms.batch,'-') as Batch_code,ifnull(cm.course,'-') as Course_name,ifnull(cm.uname,'-') as University,ifnull(sms.cid,'-') as Course_id,ifnull(sms.cmts,'-') as Comments,ifnull(sms.stf,'-') as Amount,ifnull(sms.branch,'-') as Branch_code,ifnull(std.address,'-') as address,ifnull(std.AlternateNumber,'') as AlternateNumber
from
(SELECT FeesID as fid,BatchCode as batch,StudentID as sid,CourseID as cid,FeesType as ftype,sum(CourseFees) as cf,Sum(STFOrWR) as stf,sum(Others) as others,Comments as cmts,BranchCode as branch FROM T_Students_Fees_Status
where STFOrWR != ''
-group by sid,batch,cid) as sms
-left join
- (SELECT FeesID as fid,BatchCode as batch,StudentID as sid,CourseID as cid,FeesType as ftype FROM T_Students_Fees_Status
- group by sid,cid,batch) as sfs on sfs.sid=sms.sid and sfs.fid=sms.fid
+group by sid,fid,batch,cid) as sms
left join
- (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,EnrollmentID as eid,BranchID as branch FROM T_Student_CourseDetails) as scd on scd.sid=sms.sid and scd.cid=sfs.cid
+ (SELECT StudentID as sid,UniversityID as uid,CourseID as cid,EnrollmentID as eid,BranchID as branch FROM T_Student_CourseDetails) as scd on scd.sid=sms.sid and scd.cid=sms.cid
left join
- (SELECT ID as cid,CourseID as ccid,FeesType as ftype,Sem_Year as syear FROM T_Course_Fees_Details) as cfd on cfd.ccid=scd.cid and cfd.cid=sfs.ftype
+ (SELECT ID as cid,CourseID as ccid,FeesType as ftype,Sem_Year as syear FROM T_Course_Fees_Details) as cfd on cfd.ccid=sms.cid and cfd.cid=sms.ftype
left join
(SELECT CourseID as cid,cm.UniversityID as cuid,u.UniversityID as uid,CourseName as course,
UniversityName as uname,cm.BranchCode as branch FROM T_CourseMaster as cm
left join T_UniversityMaster as u on u.UniversityID=cm.UniversityID
group by cid
order by CourseID)
- as cm on cm.cid=cfd.ccid
+ as cm on cm.cid=sms.cid
left join
(SELECT StudentID as sid,MobileNumber as phone,IsActive as active,FirstName as name,Fathername as father,PermanentAddress as address,AlternateNumber FROM T_StudentDetails) as std on std.sid=sms.sid
where std.active = 1 and sms.branch = '".$br."'
@@ -646,7 +644,7 @@ left join
if ($bat!= ''){
- $sql.=" and sfs.batch = '".$bat."'";
+ $sql.=" and sms.batch = '".$bat."'";
}
if ($u!= ''){
@@ -837,10 +835,7 @@ from T_Lead_Tracking_Followup as ltf
$batchDetails = $this->db->get(BATCH);
return $batchDetails->result();
}
-
-
-
- public function GetAllUniversity($branchId)
+ public function GetAllUniversity($branchId)
{
$this->db->select('UniversityID,UniversityName');
$this->db->from('T_UniversityMaster');
@@ -884,9 +879,9 @@ JOIN T_StudentDetails ON T_StudentDetails.StudentID=T_Student_CourseDetails.Stud
JOIN T_UniversityMaster ON T_UniversityMaster.UniversityID=T_Student_CourseDetails.UniversityID JOIN T_CourseMaster ON T_CourseMaster.CourseID=T_Student_CourseDetails.CourseID
left JOIN T_Registration_Details ON T_Registration_Details.CourseID = T_Student_CourseDetails.CourseID and T_Registration_Details.StudentID=T_Student_CourseDetails.StudentID
left JOIN T_BatchMaster ON T_BatchMaster.BatchCode = T_Registration_Details.BatchCode
-WHERE T_Registration_Details.RegistrationType = ? and str_to_date(DOJ,?)>=? and str_to_date(DOJ,?)<=? and T_Registration_Details.RegistrationMode=?';
+WHERE T_Registration_Details.RegistrationType = ? and str_to_date(DOJ,?)>=? and str_to_date(DOJ,?)<=? and T_Registration_Details.RegistrationMode=? and T_Student_CourseDetails.UniversityID=? group by T_Registration_Details.StudentID';
-$query = $this->db->query($subQuery,array(NewReg,'%d-%m-%Y',$fromd,'%d-%m-%Y',$tod,'1'));
+$query = $this->db->query($subQuery,array(NEWREGISTRATION_CONST,'%d-%m-%Y',$fromd,'%d-%m-%Y',$tod,'1',$university));
$searchDetails =$query->result();
diff --git a/Apollo/assets/i18n/en.json b/Apollo/assets/i18n/en.json
index 142041a4..43b1900a 100755
--- a/Apollo/assets/i18n/en.json
+++ b/Apollo/assets/i18n/en.json
@@ -83,16 +83,16 @@
"studmatstatus": "STUDY MATERIAL STATUS ",
"mstatus": "MARK CARD STATUS ",
"certificate_status": "CERTIFICATE STATUS ",
- "certificate_mark_status": "MARKCARD/CERTIFICATE ISSUED STATUS ",
+ "certificate_mark_status": "MARKS CARD/ CERTIFICATES - RECEIVED/ ISSUED STATUS REPORT",
"expense": "EXPENSE REPORT ",
"answer_booklets": "ANSWER BOOKLETS STATUS REPORT ",
- "app_pending": "APPLICATION PENDING STUDENT LIST REPORT",
+ "app_pending": "NEW & RE-REG FORM STATUS REPORT",
"doc_pending": "STUDENT DOCUMENTS PENDING REPORT",
"wav_ref": "WAIVER AND REFERAL REPORT",
"examfee": "EXAM WRITING FEE REPORT",
"balfee": "FEE BALANCE REPORT",
"lead": "LEAD TRACKING REPORT",
- "newreg":"NEW REG REPORT"
+ "newreg":"NEW REG REPORT"
},
"student": {
diff --git a/Apollo/assets/images/logo.png b/Apollo/assets/images/logo.png
old mode 100755
new mode 100644
index 95ad2fde..b518ade7
Binary files a/Apollo/assets/images/logo.png and b/Apollo/assets/images/logo.png differ
diff --git a/Apollo/assets/js/controllers/dashboardCtrl.js b/Apollo/assets/js/controllers/dashboardCtrl.js
index e98ad427..56cc608f 100755
--- a/Apollo/assets/js/controllers/dashboardCtrl.js
+++ b/Apollo/assets/js/controllers/dashboardCtrl.js
@@ -292,6 +292,7 @@ app.controller('OnotherCtrl', ["$scope", "toaster", "$filter", "$http", "API_POI
$scope.getUniversityRegisteredDetails = function () {
$scope.registerdStudentDetails="";
$scope.universityFeesDetails="";
+ $scope.batchFeesDetails="";
$scope.notEmptyRegistration=true;
var req = {
method: 'POST',
@@ -308,10 +309,13 @@ app.controller('OnotherCtrl', ["$scope", "toaster", "$filter", "$http", "API_POI
$scope.notEmptyRegistration=response.data.resultStatus;
$scope.registerdStudentDetails=response.data.details;
$scope.universityFeesDetails=response.data.universityFeesDetails;
+ $scope.batchFeesDetails=response.data.batchFeesDetails;
+
} else {
$scope.registerdStudentDetails="";
$scope.universityFeesDetails="";
+ $scope.batchFeesDetails="";
$scope.notEmptyRegistration=false;
}
});
diff --git a/Apollo/assets/js/controllers/datacorrectionCtrl.js b/Apollo/assets/js/controllers/datacorrectionCtrl.js
index ba1bcf06..eeab03dc 100644
--- a/Apollo/assets/js/controllers/datacorrectionCtrl.js
+++ b/Apollo/assets/js/controllers/datacorrectionCtrl.js
@@ -130,25 +130,34 @@ app.controller('datacorrectionCtrl', ["$scope","$rootScope","toaster", "$filter"
- $scope.updatestatus = function (myModel, form, loading)
- {
-//alert(myModel.ID)
+$scope.updatestatus = function (myModel, form, loading)
+{
-//alert(myModel.Reason);
+var firstError = null;
+ if (form.$invalid) {
+
+ var field = null, firstError = null;
+ for (field in form) {
+ if (field[0] != '$') {
+ if (firstError === null && !form[field].$valid) {
+ firstError = form[field].$name;
+ }
+ if (form[field].$pristine) {
+ form[field].$dirty = true;
+ }
+ }
+ }
+ angular.element('.ng-invalid[name=' + firstError + ']').focus();
+ swal("Please Enter Reason!", "", "error");
+ } else {
var d = new Date(myModel.Date);
-// console.log(d.getUTCDate()); // Hours
-// console.log(d.getUTCMonth());
-// console.log(d.getUTCFullYear());
-
var mdate = d.getUTCDate() + 1;
var mmonth = d.getUTCMonth() + 1;
var myear = d.getUTCFullYear();
var CDate = mdate+"-"+mmonth+"-"+myear;
//console.log(CDate)
-
-
var IsActive = '';
if(myModel.IsActive == true)
@@ -189,8 +198,10 @@ else if(myModel.IsActive == false)
$scope.close();
});
+
+ }
- };
+};
diff --git a/Apollo/assets/js/controllers/feesStatusCtrl.js b/Apollo/assets/js/controllers/feesStatusCtrl.js
index becec604..99e94d3b 100755
--- a/Apollo/assets/js/controllers/feesStatusCtrl.js
+++ b/Apollo/assets/js/controllers/feesStatusCtrl.js
@@ -2323,7 +2323,7 @@ app.controller('FeesModalInstanceCtrl', ["$scope", "$modalInstance", "$timeout",
//testing for print
$scope.printPdf = function (print) {
-
+
var innerContents = document.getElementById(print).innerHTML;
var popupWinindow = window.open('', '_blank', 'width=1200,height=700,scrollbars=no,menubar=no,toolbar=no,location=no,status=no,titlebar=no');
@@ -2565,148 +2565,168 @@ $scope.open = function(coursefiltered,Subjects,sem){
});
};
$scope.generatePDF = function(){
- var sem = "Sem/Year:"+$scope.sem;
+ var innerContents = document.getElementById("reregisterform").innerHTML;
+
+ var popupWinindow = window.open('', '_blank', 'width=1200,height=700,scrollbars=no,menubar=no,toolbar=no,location=no,status=no,titlebar=no');
+ popupWinindow.document.open();
+ popupWinindow.document.write('');
+ popupWinindow.document.write('');
+ popupWinindow.document.write(innerContents);
+ popupWinindow.document.write('');
+ popupWinindow.document.write('');
+ popupWinindow.document.write('');
+ popupWinindow.document.write('');
+ //popupWinindow.document.write(innerContents);
+ popupWinindow.document.write('');
+ popupWinindow.document.close();
+ popupWinindow.focus();
+ popupWinindow.print();
+ popupWinindow.close();
+ // var sem = "Sem/Year:"+$scope.sem;
- var universityaddress = encodeURIComponent($scope.Course.Address).replace(/[%2C %20]/g,' ');
- $scope.universityAddress = universityaddress.replace(" "," ");;
- $scope.universitydetails = "Mobile: "+$scope.Course.UnivMobileNumber+",E-mail id:"+$scope.Course.EmailID;
- $scope.Enroll = "Enrolment No: ";
- $scope.courseDetails = "Course Name: "+$scope.Course.CourseName+" specialization: "+$scope.Course.Specilization +sem
+ // var universityaddress = encodeURIComponent($scope.Course.Address).replace(/[%2C %20]/g,' ');
+ // $scope.universityAddress = universityaddress.replace(" "," ");;
+ // $scope.universitydetails = "Mobile: "+$scope.Course.UnivMobileNumber+",E-mail id:"+$scope.Course.EmailID;
+ // $scope.Enroll = "Enrolment No: ";
+ // $scope.courseDetails = "Course Name: "+$scope.Course.CourseName+" specialization: "+$scope.Course.Specilization +sem
- $scope.StudentName = "Name of the Candidate: "+$scope.Course.Firstname +' '+ $scope.Course.Lastname;
- $scope.StudentFatername = "Father's Name: "+$scope.Course.Fathername;
- $scope.StudentMotherName = "Mother's Name: "+$scope.Course.MotherName;
- //var str = $scope.Student.PresentAddress;
+ // $scope.StudentName = "Name of the Candidate: "+$scope.Course.Firstname +' '+ $scope.Course.Lastname;
+ // $scope.StudentFatername = "Father's Name: "+$scope.Course.Fathername;
+ // $scope.StudentMotherName = "Mother's Name: "+$scope.Course.MotherName;
+ // //var str = $scope.Student.PresentAddress;
- var str = encodeURIComponent($scope.Course.PermanentAddress).replace(/[%2C %20 %0A]/g,' ');
+ // var str = encodeURIComponent($scope.Course.PermanentAddress).replace(/[%2C %20 %0A]/g,' ');
- // str.replace("%0A"," ");
- // str.replace("%20"," ");
- // str.replace("%2C"," ");
- $scope.StudnetAddress = "Address: "+ str.replace(" "," ");
- $scope.StudentPin = "Pincode: .................. Mobile No: "+$scope.Course.MobileNumber+" Email ID: "+$scope.Course.EmailID;
+ // // str.replace("%0A"," ");
+ // // str.replace("%20"," ");
+ // // str.replace("%2C"," ");
+ // $scope.StudnetAddress = "Address: "+ str.replace(" "," ");
+ // $scope.StudentPin = "Pincode: .................. Mobile No: "+$scope.Course.MobileNumber+" Email ID: "+$scope.Course.EmailID;
- // var sem1 = doc.autoTableHtmlToJson(document.getElementById(subject));
- var universityname = $scope.Course.UniversityName;
- var universityCap = universityname.toUpperCase();
- var doc = new jsPDF('A4');
- var img = document.getElementById("logo");
- var canvas = document.createElement("canvas");
- canvas.width = 100;
- canvas.height = 100;
- var ctx = canvas.getContext("2d");
- ctx.drawImage(img, 0, 0,100,100);
- var dataURL = canvas.toDataURL("image/png");
+ // // var sem1 = doc.autoTableHtmlToJson(document.getElementById(subject));
+ // var universityname = $scope.Course.UniversityName;
+ // var universityCap = universityname.toUpperCase();
+ // var doc = new jsPDF('A4');
+ // var img = document.getElementById("logo");
+ // var canvas = document.createElement("canvas");
+ // canvas.width = 100;
+ // canvas.height = 100;
+ // var ctx = canvas.getContext("2d");
+ // ctx.drawImage(img, 0, 0,100,100);
+ // var dataURL = canvas.toDataURL("image/png");
- doc.rect(10, 10, 190, 280);
+ // doc.rect(10, 10, 190, 280);
- doc.text(70, 20, universityCap);
- doc.text(80, 26,$scope.universityAddress);
- doc.addImage(dataURL, 'jpeg', 50, 13, 10, 10);
- doc.setFontSize(14);
- doc.text(70,32,"RE-REGISTRATION FORM");
- doc.setFontSize(12);
+ // doc.text(70, 20, universityCap);
+ // doc.text(80, 26,$scope.universityAddress);
+ // doc.addImage(dataURL, 'jpeg', 50, 13, 10, 10);
+ // doc.setFontSize(14);
+ // doc.text(70,32,"RE-REGISTRATION FORM");
+ // doc.setFontSize(12);
- doc.text(40,42,$scope.universitydetails);
- doc.setFontSize(10);
- doc.setFontSize(10);
- var formdetails = "The form should be complete in all respects and to be filled by student in English CAPITAL letters in blue /black ink.";
- var details = doc.splitTextToSize(formdetails,200);
- doc.text(15,50,details);
+ // doc.text(40,42,$scope.universitydetails);
+ // doc.setFontSize(10);
+ // doc.setFontSize(10);
+ // var formdetails = "The form should be complete in all respects and to be filled by student in English CAPITAL letters in blue /black ink.";
+ // var details = doc.splitTextToSize(formdetails,200);
+ // doc.text(15,50,details);
- doc.setFontSize(12);
- doc.line(10, 45, 200, 45);
- var col = 45;
- var EnLen = $scope.Course.EnrollmentID.length;
- //console.log(EnLen);
- var k = 0;
- if(EnLen !=0){
- while( k<= EnLen-1){
- //console.log(k);
+ // doc.setFontSize(12);
+ // doc.line(10, 45, 200, 45);
+ // var col = 45;
+ // var EnLen = $scope.Course.EnrollmentID.length;
+ // //console.log(EnLen);
+ // var k = 0;
+ // if(EnLen !=0){
+ // while( k<= EnLen-1){
+ // //console.log(k);
- doc.text(15,60,$scope.Enroll);doc.rect(col,57,5,5);
- col = col+1;
- doc.text(col,61,$scope.Course.EnrollmentID[k]);
- col = parseInt(col)+4;
- k++;
- }
- }else{
- doc.text(15,60,$scope.Enroll); doc.rect(45,55,5,5);doc.rect(50,55,5,5);doc.rect(55,55,5,5);doc.rect(60,55,5,5);doc.rect(65,55,5,5);doc.rect(70,55,5,5);doc.rect(75,55,5,5);doc.rect(80,55,5,5);doc.rect(85,55,5,5);doc.rect(90,55,5,5);doc.rect(95,55,5,5);doc.rect(100,55,5,5);doc.rect(105,55,5,5);doc.rect(110,55,5,5);doc.rect(115,55,5,5);doc.rect(120,55,5,5);doc.rect(125,55,5,5);
- // doc.text(46,59,$scope.Student.EnrollmentID[0]);doc.text(51,59,$scope.Student.EnrollmentID[1]);doc.text(56,59,$scope.Student.EnrollmentID[2]);doc.text(61,59,$scope.Student.EnrollmentID[3]);doc.text(66,59,$scope.Student.EnrollmentID[4]);
- // doc.text(71,59,$scope.Student.EnrollmentID[5]);doc.text(76,59,$scope.Student.EnrollmentID[6]);doc.text(81,59,$scope.Student.EnrollmentID[7]);doc.text(86,59,$scope.Student.EnrollmentID[8]);doc.text(91,59,$scope.Student.EnrollmentID[9]);
- // doc.text(96,59,$scope.Student.EnrollmentID[10]);doc.text(101,59,$scope.Student.EnrollmentID[11]);doc.text(106,59,$scope.Student.EnrollmentID[12]);
- // //doc.text(111,59,$scope.Student.EnrollmentID[13]);doc.text(116,59,$scope.Student.EnrollmentID[14]);doc.text(121,59,$scope.Student.EnrollmentID[15]);
- }
- doc.setFontSize(10);
- doc.text(15,70,$scope.courseDetails);
- doc.setFontSize(12);
- doc.text(15,80,"Examination Session: January ");doc.rect(73,77,5,5);doc.text(80,80,"June");doc.rect(90,77,5,5);doc.text(100,80,"Semester Mode");doc.rect(131,77,5,5);doc.text(140,80,"Yearly Mode");doc.rect(165,77,5,5);
- // doc.autoTable(sem1.columns, sem1.data, {margin: {top: 100},theme:'grid'});
+ // doc.text(15,60,$scope.Enroll);doc.rect(col,57,5,5);
+ // col = col+1;
+ // doc.text(col,61,$scope.Course.EnrollmentID[k]);
+ // col = parseInt(col)+4;
+ // k++;
+ // }
+ // }else{
+ // doc.text(15,60,$scope.Enroll); doc.rect(45,55,5,5);doc.rect(50,55,5,5);doc.rect(55,55,5,5);doc.rect(60,55,5,5);doc.rect(65,55,5,5);doc.rect(70,55,5,5);doc.rect(75,55,5,5);doc.rect(80,55,5,5);doc.rect(85,55,5,5);doc.rect(90,55,5,5);doc.rect(95,55,5,5);doc.rect(100,55,5,5);doc.rect(105,55,5,5);doc.rect(110,55,5,5);doc.rect(115,55,5,5);doc.rect(120,55,5,5);doc.rect(125,55,5,5);
+ // // doc.text(46,59,$scope.Student.EnrollmentID[0]);doc.text(51,59,$scope.Student.EnrollmentID[1]);doc.text(56,59,$scope.Student.EnrollmentID[2]);doc.text(61,59,$scope.Student.EnrollmentID[3]);doc.text(66,59,$scope.Student.EnrollmentID[4]);
+ // // doc.text(71,59,$scope.Student.EnrollmentID[5]);doc.text(76,59,$scope.Student.EnrollmentID[6]);doc.text(81,59,$scope.Student.EnrollmentID[7]);doc.text(86,59,$scope.Student.EnrollmentID[8]);doc.text(91,59,$scope.Student.EnrollmentID[9]);
+ // // doc.text(96,59,$scope.Student.EnrollmentID[10]);doc.text(101,59,$scope.Student.EnrollmentID[11]);doc.text(106,59,$scope.Student.EnrollmentID[12]);
+ // // //doc.text(111,59,$scope.Student.EnrollmentID[13]);doc.text(116,59,$scope.Student.EnrollmentID[14]);doc.text(121,59,$scope.Student.EnrollmentID[15]);
+ // }
+ // doc.setFontSize(10);
+ // doc.text(15,70,$scope.courseDetails);
+ // doc.setFontSize(12);
+ // doc.text(15,80,"Examination Session: January ");doc.rect(73,77,5,5);doc.text(80,80,"June");doc.rect(90,77,5,5);doc.text(100,80,"Semester Mode");doc.rect(131,77,5,5);doc.text(140,80,"Yearly Mode");doc.rect(165,77,5,5);
+ // // doc.autoTable(sem1.columns, sem1.data, {margin: {top: 100},theme:'grid'});
- doc.line(10, 83, 200, 83);
- doc.text(15,88,$scope.StudentName);
- doc.text(60,89,"......................................................................................................................");
- doc.text(15,95,$scope.StudentFatername);
- doc.text(43,96,"....................................................................................................................................");
- doc.text(15,102,$scope.StudentMotherName);
- doc.text(43,103,"....................................................................................................................................");
+ // doc.line(10, 83, 200, 83);
+ // doc.text(15,88,$scope.StudentName);
+ // doc.text(60,89,"......................................................................................................................");
+ // doc.text(15,95,$scope.StudentFatername);
+ // doc.text(43,96,"....................................................................................................................................");
+ // doc.text(15,102,$scope.StudentMotherName);
+ // doc.text(43,103,"....................................................................................................................................");
- doc.text(15,110,$scope.StudnetAddress);
- doc.text(30,111,"................................................................................................................................................");
- doc.text(15,121,$scope.StudentPin);
- doc.text
- doc.line(10, 125, 200,125);
- doc.text(45,130,"SUBJECT / PAPER IN WHICH CANDIDATE APPEARING")
- doc.line(10, 131, 200, 131);
- doc.text(20,135,"SR.NO");
+ // doc.text(15,110,$scope.StudnetAddress);
+ // doc.text(30,111,"................................................................................................................................................");
+ // doc.text(15,121,$scope.StudentPin);
+ // doc.text
+ // doc.line(10, 125, 200,125);
+ // doc.text(45,130,"SUBJECT / PAPER IN WHICH CANDIDATE APPEARING")
+ // doc.line(10, 131, 200, 131);
+ // doc.text(20,135,"SR.NO");
- doc.text(60,135,"Subject Code");
- doc.text(110,135,"Subject/Paper Code");
- doc.line(10,137,200,137);
- var row = 137;
- var no = 1;
- //console.log();
- angular.forEach($scope.Subject[0],function(subjectData,key){
- //for(var i=0;i<=$scope.Subject[key].length-1;i++){
- // console.log(subjectData);
- doc.line(10,row,200,row);
- no = no.toString();
- doc.text(20,row+5,no);
- doc.text(65,row+5,subjectData.SubjectCode);
- doc.setFontSize(10);
- doc.text(100,row+5,subjectData.SubjectName);
+ // doc.text(60,135,"Subject Code");
+ // doc.text(110,135,"Subject/Paper Code");
+ // doc.line(10,137,200,137);
+ // var row = 137;
+ // var no = 1;
+ // //console.log();
+ // angular.forEach($scope.Subject[0],function(subjectData,key){
+ // //for(var i=0;i<=$scope.Subject[key].length-1;i++){
+ // // console.log(subjectData);
+ // doc.line(10,row,200,row);
+ // no = no.toString();
+ // doc.text(20,row+5,no);
+ // doc.text(65,row+5,subjectData.SubjectCode);
+ // doc.setFontSize(10);
+ // doc.text(100,row+5,subjectData.SubjectName);
- row = row+6;
- no = parseInt(no)+1;
- doc.line(10,row,200,row);
+ // row = row+6;
+ // no = parseInt(no)+1;
+ // doc.line(10,row,200,row);
- });
- var index = 14;
- var len = index-$scope.Subject[0].length;
- //console.log(len);
- for(var j=0;j<=len;j++){
- if(no <=9){
- no = no.toString();
- doc.text(20,row+5,no);
- }else{
- no = no.toString();
- doc.text(19,row+5,no);
- }
- // doc.text(75,row+5,"--");
- // doc.text(120,row+5,"--");
- row = row+6;
+ // });
+ // var index = 14;
+ // var len = index-$scope.Subject[0].length;
+ // //console.log(len);
+ // for(var j=0;j<=len;j++){
+ // if(no <=9){
+ // no = no.toString();
+ // doc.text(20,row+5,no);
+ // }else{
+ // no = no.toString();
+ // doc.text(19,row+5,no);
+ // }
+ // // doc.text(75,row+5,"--");
+ // // doc.text(120,row+5,"--");
+ // row = row+6;
- no = parseInt(no)+1;
- doc.line(10,row,200,row);
- }
- doc.line(10,240,200,240);
- doc.text(15,250,"Fees Details: Cash / Cheque / DD");
- doc.text(15,260,"DD No / Cheque No ....................... Dated ............... Bank ....................");
- doc.text(15,270,"Amount ...................");
- doc.text(150,280,"Signature of Candidate");
+ // no = parseInt(no)+1;
+ // doc.line(10,row,200,row);
+ // }
+ // doc.line(10,240,200,240);
+ // doc.text(15,250,"Fees Details: Cash / Cheque / DD");
+ // doc.text(15,260,"DD No / Cheque No ....................... Dated ............... Bank ....................");
+ // doc.text(15,270,"Amount ...................");
+ // doc.text(150,280,"Signature of Candidate");
- doc.save($scope.Course.Firstname +'_'+ $scope.Course.Lastname+'_'+$scope.sem+'.pdf');
+ // doc.save($scope.Course.Firstname +'_'+ $scope.Course.Lastname+'_'+$scope.sem+'.pdf');
}
diff --git a/Apollo/assets/js/controllers/generateHallTicketCtrl.js b/Apollo/assets/js/controllers/generateHallTicketCtrl.js
index 32eee39c..8007c128 100755
--- a/Apollo/assets/js/controllers/generateHallTicketCtrl.js
+++ b/Apollo/assets/js/controllers/generateHallTicketCtrl.js
@@ -638,28 +638,28 @@ app.controller('HallTicketPDFCtrl', ["$scope", "$modalInstance", "pdfitems", fun
switch(i)
{
case 0:
- var firstTableID = tableid+'year10';
+ var firstTableID = tableid+'year1'+key;
//var SecTableID = tableid+'year11';
semName = 'YEAR1';
break;
case 1:
- var firstTableID = tableid+'year20';
+ var firstTableID = tableid+'year2'+key;
//var SecTableID = tableid+'year21';
semName = 'YEAR2';
break;
case 2:
- var firstTableID = tableid+'year30';
+ var firstTableID = tableid+'year3'+key;
//var SecTableID = tableid+'year31';
semName = 'YEAR3';
break;
case 4:
- var firstTableID = tableid+'year40';
+ var firstTableID = tableid+'year4'+key;
//var SecTableID = tableid+'year41';
semName = 'YEAR4';
diff --git a/Apollo/assets/js/controllers/newreg_reportCtrl.js b/Apollo/assets/js/controllers/newreg_reportCtrl.js
index ac7c32c1..d193bc8b 100644
--- a/Apollo/assets/js/controllers/newreg_reportCtrl.js
+++ b/Apollo/assets/js/controllers/newreg_reportCtrl.js
@@ -83,16 +83,55 @@ app.controller('newreg_reportCtrl', ["$scope","$rootScope","toaster", "$filter",
//$scope.opinctotal='';
$scope.newreglist='';
$scope.isLoaderShow ='';
+$scope.load = '';
+$scope.isShow= '';
+$scope.fromd='';
+$scope.tod='';
$scope.getDetails = function (form,myModel)
{
// alert('in')
- console.log(form.$dirty);
+ //console.log(form.$dirty);
var from = $scope.filters.from_date;
var to = $scope.filters.to_date;
- var university = myModel.myUnivSearch
+ var university = myModel.myUnivSearch ;
// console.log(from)
+
+
+
+
+var f = new Date(from),
+month = '' + (f.getMonth() + 1),
+day = '' + f.getDate(),
+year = f.getFullYear();
+
+if (month.length < 2) month = '0' + month;
+if (day.length < 2) day = '0' + day;
+
+var from_dt = [day, month ,year].join('-');
+
+
+
+var t = new Date(to),
+month = '' + (t.getMonth() + 1),
+day = '' + t.getDate(),
+year = t.getFullYear();
+
+if (month.length < 2) month = '0' + month;
+if (day.length < 2) day = '0' + day;
+
+var to_dt = [day, month ,year].join('-');
+
+
+$scope.fromd = from_dt;
+$scope.tod = to_dt;
+
+
+
+
+
+
var getstudentdetails = {
method: 'POST',
@@ -110,16 +149,20 @@ $scope.isLoaderShow ='';
$http(getstudentdetails).then(function (response) {
- if(response.data.status == 200)
+ if(response.data.status == 200 && response.data.searchst==true)
{
+
+ console.log(response.data);
$scope.newreglist = response.data.details;
- $scope.isLoaderShow = true;
+ $scope.isShow=true;
+ $scope.isLoaderShow=false;
}
else
{
- $scope.isLoaderShow=false;
+ $scope.isLoaderShow=true;
+ $scope.isShow=false;
}
@@ -130,12 +173,23 @@ $scope.isLoaderShow ='';
- var mystyle = {
- sheetid: 'New Registration List',
+
+
+
+
+ $scope.exportData = function ()
+ {
+ //alert()
+
+ $scope.sam = 'New-Registration List from '+$scope.fromd+' to '+$scope.tod;
+
+
+ var mystyle = {
+ sheetid:$scope.sam,
headers: true,
caption: {
- title:'New Registration List',
- width: '500px',
+ title: $scope.sam,
+ width: '1000px',
style:'font-size:50px;bold:true'
},
// style:'background:#00FF00',
@@ -144,12 +198,7 @@ $scope.isLoaderShow ='';
},
};
-
-
-
- $scope.exportData = function ()
- {
- //alert()
+ console.log(mystyle);
diff --git a/Apollo/assets/js/controllers/report_app_pendingCtrl.js b/Apollo/assets/js/controllers/report_app_pendingCtrl.js
index 626616b6..4a860046 100755
--- a/Apollo/assets/js/controllers/report_app_pendingCtrl.js
+++ b/Apollo/assets/js/controllers/report_app_pendingCtrl.js
@@ -150,7 +150,7 @@ app.controller('report_app_pendingCtrl', ["$scope", "$filter","$rootScope","$mod
$scope.exportData = function () {
- alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Admission_date as AdmissionDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,Status as ApplicationPendingStatus INTO XLS("Application_pending_student_list.xls",?) FROM ?',[mystyle,$scope.app_pending_data]);
+ alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Admission_date as InititalPaymentDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,Status as ApplicationPendingStatus,formtype as FormType,appdate as Date INTO XLS("Application_pending_student_list.xls",?) FROM ?',[mystyle,$scope.app_pending_data]);
};
diff --git a/Apollo/assets/js/controllers/report_balfeeCtrl.js b/Apollo/assets/js/controllers/report_balfeeCtrl.js
index 28a22b1f..54d58da3 100755
--- a/Apollo/assets/js/controllers/report_balfeeCtrl.js
+++ b/Apollo/assets/js/controllers/report_balfeeCtrl.js
@@ -173,10 +173,10 @@ app.controller('report_balfeeCtrl', ["$scope", "$filter","$rootScope","$modal",
}
//Export to excel
var mystyle = {
- sheetid: 'BALANCE FEE STATUS REPORT',
+ sheetid: 'FEE BALANCE REPORT',
headers: true,
caption: {
- title:'BALANCE FEE STATUS REPORT',
+ title:'FEE BALANCE REPORT',
width: '300px',
style:'font-size:50px;'
},
diff --git a/Apollo/assets/js/controllers/report_doc_pendingCtrl.js b/Apollo/assets/js/controllers/report_doc_pendingCtrl.js
index a82e9624..605ba51f 100755
--- a/Apollo/assets/js/controllers/report_doc_pendingCtrl.js
+++ b/Apollo/assets/js/controllers/report_doc_pendingCtrl.js
@@ -150,7 +150,7 @@ app.controller('report_doc_pendingCtrl', ["$scope", "$filter","$rootScope","$mod
$scope.exportData = function () {
- alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Admission_date as AdmissionDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,adate as DocumentAppliedDate,certname as DocumentName,Status as DocumentPendingStatus INTO XLS("Document_pending_student_list.xls",?) FROM ?',[mystyle,$scope.doc_pending_data]);
+ alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Admission_date as AdmissionDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,fdate as Followupdate,certname as DocumentName INTO XLS("Document_pending_student_list.xls",?) FROM ?',[mystyle,$scope.doc_pending_data]);
};
/*modal controller
* */
diff --git a/Apollo/assets/js/controllers/report_markcard_statusCtrl.js b/Apollo/assets/js/controllers/report_markcard_statusCtrl.js
index 0c588387..7792ce41 100755
--- a/Apollo/assets/js/controllers/report_markcard_statusCtrl.js
+++ b/Apollo/assets/js/controllers/report_markcard_statusCtrl.js
@@ -150,7 +150,7 @@ app.controller('report_markcard_statusCtrl', ["$scope", "$filter","$rootScope",
$scope.exportData = function () {
- alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Initial_paid_date as InitialPaidDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Roll_NO as RollNO,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,CAST(Balance_Fee AS NUMBER) as BalanceFee,Status as MarkCardStatus,Date as Date INTO XLS("Markcard_status.xls",?) FROM ?',[mystyle,$scope.markcard_data]);
+ alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Initial_paid_date as InitialPaidDate,Enrollment_id as EnrollmentID,Student_name as StudentName,Roll_NO as RollNO,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University as University,CAST(Balance_Fee AS NUMBER) as BalanceFee,appdate as ApplicationSentDate,ansdate as AnswerBookletSentDate,Status as MarkCardStatus,Date as Date INTO XLS("Markcard_status.xls",?) FROM ?',[mystyle,$scope.markcard_data]);
};
/*modal controller
* */
diff --git a/Apollo/assets/js/controllers/report_study_material_statusCtrl.js b/Apollo/assets/js/controllers/report_study_material_statusCtrl.js
index ab3ec6ac..9c169537 100755
--- a/Apollo/assets/js/controllers/report_study_material_statusCtrl.js
+++ b/Apollo/assets/js/controllers/report_study_material_statusCtrl.js
@@ -142,7 +142,7 @@ app.controller('report_study_material_statusCtrl', ["$scope", "$filter","$rootSc
$scope.exportData = function () {
- alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Initial_paid_date as InitialPaidDate,Enrollment_id as EnrollmentId,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University,Status as StudyMaterial_Status,CAST(Balance_fee AS NUMBER) as BalanceFee,Date INTO XLS("Study_material_status.xls",?) FROM ?',[mystyle,$scope.study_mat_data]);
+ alasql('SELECT CAST(SL_NO AS NUMBER) as SLNO,Initial_paid_date as InitialPaidDate,Enrollment_id as EnrollmentId,Student_name as StudentName,Father_name as FatherName,Course_name as CourseName,Sem_year as SemYear,CAST(Phone_number AS NUMBER) as PhoneNumber,University,Status as StudyMaterial_Status,Date,CAST(Balance_fee AS NUMBER) as BalanceFee INTO XLS("Study_material_status.xls",?) FROM ?',[mystyle,$scope.study_mat_data]);
};
diff --git a/Apollo/assets/views/dashboard.html b/Apollo/assets/views/dashboard.html
index b7ca4661..6e35d5ad 100755
--- a/Apollo/assets/views/dashboard.html
+++ b/Apollo/assets/views/dashboard.html
@@ -23,6 +23,7 @@
+
@@ -272,21 +278,21 @@
+
diff --git a/Apollo/assets/views/daybook/dayBookApproval.html b/Apollo/assets/views/daybook/dayBookApproval.html
index 6d05da34..cfe19d6c 100755
--- a/Apollo/assets/views/daybook/dayBookApproval.html
+++ b/Apollo/assets/views/daybook/dayBookApproval.html
@@ -69,7 +69,8 @@
-
+
+
+
Type is Required
-
+ -->
+
diff --git a/Apollo/assets/views/daybook/dayBookadminApproval.html b/Apollo/assets/views/daybook/dayBookadminApproval.html
index 4a4a2241..df1ac54c 100755
--- a/Apollo/assets/views/daybook/dayBookadminApproval.html
+++ b/Apollo/assets/views/daybook/dayBookadminApproval.html
@@ -76,7 +76,7 @@
-
+
+
Type is Required
-
+
-->
diff --git a/Apollo/assets/views/daybook/daybooksuperAdminApproval.html b/Apollo/assets/views/daybook/daybooksuperAdminApproval.html
index 96ec626a..37d0a046 100755
--- a/Apollo/assets/views/daybook/daybooksuperAdminApproval.html
+++ b/Apollo/assets/views/daybook/daybooksuperAdminApproval.html
@@ -51,7 +51,7 @@
-
+
diff --git a/Apollo/assets/views/edit_daybookentries.html b/Apollo/assets/views/edit_daybookentries.html
index f6a89d89..49c3874c 100644
--- a/Apollo/assets/views/edit_daybookentries.html
+++ b/Apollo/assets/views/edit_daybookentries.html
@@ -73,7 +73,7 @@
-
diff --git a/Apollo/api/application/models/Fees_status_model.php b/Apollo/api/application/models/Fees_status_model.php
index 326dcfb1..4b6896d3 100755
--- a/Apollo/api/application/models/Fees_status_model.php
+++ b/Apollo/api/application/models/Fees_status_model.php
@@ -1759,29 +1759,79 @@ class Fees_status_model extends CI_Model
if($row->ProgramType==REGULARFEES OR $row->ProgramType==LATERALFEES){
foreach ($singleFeesDetails as $Fees){
-
$insertStudyBook['Sem']=$Fees;
- // insert study material details
- $this->db->insert(STUDY_MATERIAL_STATUS, $insertStudyBook);
- // insert answer booklet details
- $this->db->insert(ANSWER_BOOKLET, $insertStudyBook);
+ // check study material status exist or not
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('Sem',$Fees);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existStudyMaterialDetails = $this->db->get(STUDY_MATERIAL_STATUS);
+ if($existStudyMaterialDetails->num_rows()<1){
- // insert mark card details
- $insertMark['Sem']=$Fees;
- $this->db->insert(CERTIFICATION_STATUS, $insertMark);
+ // insert study material details
+ $this->db->insert(STUDY_MATERIAL_STATUS, $insertStudyBook);
+ }
+ // check answer book;et exist or not
+
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existAnsBookDetails = $this->db->get(ANSWER_BOOKLET);
+ if($existAnsBookDetails->num_rows()<1) {
+ // insert answer booklet details
+ $this->db->insert(ANSWER_BOOKLET, $insertStudyBook);
+ }
+ // check certificate exist or not
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('Sem',$row->Sem_Year);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existAnsBookDetails = $this->db->get(CERTIFICATION_STATUS);
+ if($existAnsBookDetails->num_rows()<1) {
+ // insert mark card details
+ $insertMark['Sem'] = $row->Sem_Year;
+ $this->db->insert(CERTIFICATION_STATUS, $insertMark);
+ }
}
}
else{
- $insertStudyBook['Sem']=$row->Sem_Year;
- // insert study material details
- $this->db->insert(STUDY_MATERIAL_STATUS, $insertStudyBook);
- // insert answer booklet details
- $this->db->insert(ANSWER_BOOKLET, $insertStudyBook);
- // insert mark card details
- $insertMark['Sem']=$row->Sem_Year;
- $this->db->insert(CERTIFICATION_STATUS, $insertMark);
+ $insertStudyBook['Sem'] = $row->Sem_Year;
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existStudyMaterialDetails = $this->db->get(STUDY_MATERIAL_STATUS);
+ if($existStudyMaterialDetails->num_rows()<1) {
+
+ // insert study material details
+ $this->db->insert(STUDY_MATERIAL_STATUS, $insertStudyBook);
+ }
+ // check answer book;et exist or not
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existAnsBookDetails = $this->db->get(ANSWER_BOOKLET);
+ if($existAnsBookDetails->num_rows()<1) {
+ // insert answer booklet details
+ $this->db->insert(ANSWER_BOOKLET, $insertStudyBook);
+ }
+ // check certificate exist or not
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$row->FeesType);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $existAnsBookDetails = $this->db->get(CERTIFICATION_STATUS);
+ if($existAnsBookDetails->num_rows()<1) {
+ // insert mark card details
+ $insertMark['Sem'] = $row->Sem_Year;
+ $this->db->insert(CERTIFICATION_STATUS, $insertMark);
+ }
}
@@ -1793,6 +1843,7 @@ class Fees_status_model extends CI_Model
else{
$this->db->select('CertificationID');
$this->db->where('CertificateName',$fetchData[0]->FeesType);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
$this->db->where('IsActive','1');
$getEndFeesDetails = $this->db->get(CERTIFICATION_MASTER)->last_row();
if($getEndFeesDetails){
@@ -1805,8 +1856,16 @@ class Fees_status_model extends CI_Model
$insertDocs['CreatedBy']=$feesDetails['CreatedBy'];
$insertDocs['CreatedOn']=$feesDetails['CreatedOn'];
$insertDocs['CertificationType']=$getEndFeesDetails->CertificationID;
- // insert application details
- $this->db->insert(APPLICATION_STATUS,$insertDocs);
+ $this->db->select('CourseID');
+ $this->db->where('CourseID',$courseID);
+ $this->db->where('BranchCode',$feesDetails['UpdatedBy']);
+ $this->db->where('StudentID',$feesDetails['StudentID']);
+ $this->db->where('CertificationType',$getEndFeesDetails->CertificationID);
+ $existApplicationDetails = $this->db->get(APPLICATION_STATUS);
+ if($existApplicationDetails->num_rows()<1) {
+ // insert application details
+ $this->db->insert(APPLICATION_STATUS, $insertDocs);
+ }
}